---
title: "OSPAR"
description: "Terraform compliance scanning for OSPAR — assess for free, remediate with ComplyForm"
---

import { Badge } from '@astrojs/starlight/components';

<Badge text="Team" variant="caution" />
<Badge text="Financial" variant="tip" />

**Issuing body:** [ABS](https://abs.org.sg)
**Jurisdiction:** Country — Asia-Pacific
**Countries:** SG


## Assessment

Assess your infrastructure against OSPAR for free at any tier:

```bash
complyform assess --frameworks=ospar
```

## Remediation

Requires Team tier or higher ($1,999/yr) for remediation.

```bash
complyform remediate --frameworks=ospar
```

## Related Frameworks

- [IRAP](/frameworks/irap)
- [K-ISMS-P](/frameworks/k_isms_p)
- [MTCS SS](/frameworks/mtcs)
- [ISMAP](/frameworks/ismap)
